@@ -1,12 +1,14 @@
-/*********************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *
+/**
+ * Copyright (c) 2019-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- **********************************************************************/
+ *
+ * Contributors:
+ *   Red Hat, Inc. - initial API and implementation
+ */
 
 import Command from '@oclif/command'
 import ansi = require('ansi-colors')
@@ -40,7 +42,7 @@ export function createNamespaceTask(namespaceName: string, labels: {}): Listr.Li
         await che.waitNamespaceActive(namespaceName)
         task.title = `${task.title}...Done.`
       }
-    }
+    },
   }
 }
 
@@ -57,12 +59,12 @@ export function checkChectlAndCheVersionCompatibility(flags: any): Listr.ListrTa
       ctx.versionInfo = verInfo
       flags.version = VersionHelper.removeVPrefix(verInfo.name, true)
 
-      if (!ctx.isNightly && semver.lt(getProjectVersion(), flags.version)) {
+      if (!ctx.isDevVersion && semver.lt(getProjectVersion(), flags.version)) {
         throw new Error(`To deploy CodeReady Workspaces ${flags.version}, please update your crwctl first by running "crwctl update".`)
       }
 
       task.title = `${task.title}... OK`
-    }
+    },
   }
 }
 
@@ -109,14 +111,14 @@ export function downloadTemplates(flags: any): Listr.ListrTask {
       const cheHelper = new CheHelper(flags)
       await cheHelper.downloadAndUnpackTemplates(flags.installer, ctx.versionInfo.zipball_url, versionTemplatesDirPath)
       task.title = `${task.title} ... OK`
-    }
+    },
   }
 }
 
 export function createEclipseCheCluster(flags: any, kube: KubeHelper): Listr.ListrTask {
   return {
     title: `Create the Custom Resource of type ${CHE_CLUSTER_CRD} in the namespace ${flags.chenamespace}`,
-    enabled: ctx => !!ctx.customCR || !!ctx.defaultCR,
+    enabled: ctx => Boolean(ctx.customCR) || Boolean(ctx.defaultCR),
     task: async (ctx: any, task: any) => {
       ctx.isCheDeployed = true
       ctx.isPostgresDeployed = true
@@ -144,12 +146,8 @@ export function createEclipseCheCluster(flags: any, kube: KubeHelper): Listr.Lis
       ctx.isDevfileRegistryReady = ctx.isDevfileRegistryReady || cr.spec.server.externalDevfileRegistry
       ctx.isPluginRegistryReady = ctx.isPluginRegistryReady || cr.spec.server.externalPluginRegistry
 
-      if (cr.spec.server.customCheProperties && cr.spec.server.customCheProperties.CHE_MULTIUSER === 'false') {
-        flags.multiuser = false
-      }
-
       task.title = `${task.title}...done.`
-    }
+    },
   }
 }
 
@@ -171,7 +169,7 @@ export function patchingEclipseCheCluster(flags: any, kube: KubeHelper, command:
       }
       await kube.patchCheCluster(cheCluster.metadata.name, flags.chenamespace, ctx[ChectlContext.CR_PATCH])
       task.title = `${task.title}...done.`
-    }
+    },
   }
 }
 
@@ -187,7 +185,7 @@ export function retrieveCheCaCertificateTask(flags: any): Listr.ListrTask {
       if (cheCaCert) {
         const targetFile = await che.saveCheCaCert(cheCaCert)
 
-        task.title = `${task.title}... done`
+        task.title = `${task.title}...OK`
         const serverStrategy = await kube.getConfigMapValue('che', flags.chenamespace, 'CHE_INFRA_KUBERNETES_SERVER__STRATEGY')
         if (serverStrategy !== 'single-host') {
           ctx.highlightedMessages.push(getMessageImportCaCertIntoBrowser(targetFile))
@@ -195,8 +193,7 @@ export function retrieveCheCaCertificateTask(flags: any): Listr.ListrTask {
       } else {
         task.title = `${task.title}... commonly trusted certificate is used.`
       }
-
-    }
+    },
   }
 }
 
@@ -206,24 +203,6 @@ export function getMessageImportCaCertIntoBrowser(caCertFileLocation: string): s
   return message
 }
 
-export function getRetrieveKeycloakCredentialsTask(flags: any): Listr.ListrTask {
-  return {
-    title: 'Retrieving Keycloak admin credentials',
-    enabled: () => (flags.installer !== 'helm'),
-    task: async (ctx: any, task: any) => {
-      const che = new CheHelper(flags)
-      const [login, password] = await che.retrieveKeycloakAdminCredentials(flags.chenamespace)
-      if (login && password) {
-        ctx.identityProviderUsername = login
-        ctx.identityProviderPassword = password
-        task.title = `${task.title}...done`
-      } else {
-        task.title = `${task.title}...failed.`
-      }
-    }
-  }
-}
-
 /**
  * Prints important to user messages which are stored in ctx.highlightedMessages
  * Typically this task is the last task of a command.
@@ -237,10 +216,10 @@ export function getPrintHighlightedMessagesTask(): Listr.ListrTask {
       for (const message of ctx.highlightedMessages) {
         printMessageTasks.add({
           title: message,
-          task: () => { }
+          task: () => { },
         })
       }
       return printMessageTasks
-    }
+    },
   }
 }
