@@ -1,12 +1,14 @@
-/*********************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *
+/**
+ * Copyright (c) 2019-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- **********************************************************************/
+ *
+ * Contributors:
+ *   Red Hat, Inc. - initial API and implementation
+ */
 
 import Command from '@oclif/command'
 import { cli } from 'cli-ux'
@@ -17,14 +19,16 @@ import * as path from 'path'
 import { KubeHelper } from '../../api/kube'
 import { CatalogSource, Subscription } from '../../api/typings/olm'
 import { VersionHelper } from '../../api/version'
-import { CUSTOM_CATALOG_SOURCE_NAME, CVS_PREFIX, DEFAULT_CHE_OLM_PACKAGE_NAME, DEFAULT_OLM_KUBERNETES_NAMESPACE, DEFAULT_OPENSHIFT_MARKET_PLACE_NAMESPACE, KUBERNETES_OLM_CATALOG, NIGHTLY_CATALOG_SOURCE_NAME, OLM_NIGHTLY_CHANNEL_NAME, OLM_STABLE_CHANNEL_NAME, OPENSHIFT_OLM_CATALOG, OPERATOR_GROUP_NAME, SUBSCRIPTION_NAME } from '../../constants'
+import { CUSTOM_CATALOG_SOURCE_NAME, CVS_PREFIX, DEFAULT_CHE_NAMESPACE, DEFAULT_CHE_OLM_PACKAGE_NAME, DEFAULT_OLM_KUBERNETES_NAMESPACE, DEFAULT_OPENSHIFT_MARKET_PLACE_NAMESPACE, DEFAULT_OPENSHIFT_OPERATORS_NS_NAME, KUBERNETES_OLM_CATALOG, NEXT_CATALOG_SOURCE_NAME, OLM_NEXT_CHANNEL_NAME, OLM_STABLE_CHANNEL_NAME, OPENSHIFT_OLM_CATALOG, OPERATOR_GROUP_NAME, STABLE_ALL_NAMESPACES_CHANNEL_NAME, SUBSCRIPTION_NAME } from '../../constants'
 import { isKubernetesPlatformFamily } from '../../util'
 
 import { createEclipseCheCluster, createNamespaceTask, patchingEclipseCheCluster } from './common-tasks'
 
 export class OLMTasks {
   prometheusRoleName = 'prometheus-k8s'
+
   prometheusRoleBindingName = 'prometheus-k8s'
+
   /**
    * Returns list of tasks which perform preflight platform checks.
    */
@@ -45,7 +49,7 @@ export class OLMTasks {
             await kube.createRoleFromFile(yamlFilePath, flags.chenamespace)
             task.title = `${task.title}...done.`
           }
-        }
+        },
       },
       {
         enabled: () => flags['cluster-monitoring'] && flags.platform === 'openshift',
@@ -60,10 +64,12 @@ export class OLMTasks {
             await kube.createRoleBindingFromFile(yamlFilePath, flags.chenamespace)
             task.title = `${task.title}...done.`
           }
-        }
+        },
       },
       {
         title: 'Create operator group',
+        // 'stable-all-namespaces' channel install the operator in openshift-operators namespace and there already exists a pre-created operator-group.
+        enabled: (ctx: any) => ctx.operatorNamespace !== DEFAULT_OPENSHIFT_OPERATORS_NS_NAME,
         task: async (_ctx: any, task: any) => {
           if (await kube.operatorGroupExists(OPERATOR_GROUP_NAME, flags.chenamespace)) {
             task.title = `${task.title}...It already exists.`
@@ -71,7 +77,7 @@ export class OLMTasks {
             await kube.createOperatorGroup(OPERATOR_GROUP_NAME, flags.chenamespace)
             task.title = `${task.title}...created new one.`
           }
-        }
+        },
       },
       {
         title: 'Configure context information',
@@ -103,21 +109,21 @@ export class OLMTasks {
           }
 
           task.title = `${task.title}...done.`
-        }
+        },
       },
       {
         enabled: () => !VersionHelper.isDeployingStableVersion(flags) && !flags['catalog-source-name'] && !flags['catalog-source-yaml'] && flags['olm-channel'] !== OLM_STABLE_CHANNEL_NAME,
-        title: `Create nightly index CatalogSource in the namespace ${flags.chenamespace}`,
+        title: `Create next index CatalogSource in the namespace ${flags.chenamespace}`,
         task: async (ctx: any, task: any) => {
-          if (!await kube.catalogSourceExists(NIGHTLY_CATALOG_SOURCE_NAME, flags.chenamespace)) {
+          if (!await kube.catalogSourceExists(NEXT_CATALOG_SOURCE_NAME, flags.chenamespace)) {
             const catalogSourceImage = `quay.io/eclipse/eclipse-che-${ctx.generalPlatformName}-opm-catalog:preview`
             const nigthlyCatalogSource = this.constructIndexCatalogSource(flags.chenamespace, catalogSourceImage)
             await kube.createCatalogSource(nigthlyCatalogSource)
-            await kube.waitCatalogSource(flags.chenamespace, NIGHTLY_CATALOG_SOURCE_NAME)
+            await kube.waitCatalogSource(flags.chenamespace, NEXT_CATALOG_SOURCE_NAME)
           } else {
             task.title = `${task.title}...It already exists.`
           }
-        }
+        },
       },
       {
         enabled: () => flags['catalog-source-yaml'],
@@ -133,53 +139,56 @@ export class OLMTasks {
           } else {
             task.title = `${task.title}...It already exists.`
           }
-        }
+        },
       },
       {
         title: 'Create operator subscription',
         task: async (ctx: any, task: any) => {
-          if (await kube.operatorSubscriptionExists(SUBSCRIPTION_NAME, flags.chenamespace)) {
+          if (await kube.operatorSubscriptionExists(SUBSCRIPTION_NAME, ctx.operatorNamespace)) {
             task.title = `${task.title}...It already exists.`
           } else {
             let subscription: Subscription
             if (flags['catalog-source-yaml'] || flags['catalog-source-name']) {
               // custom Che CatalogSource
-              const catalogSourceNamespace = flags['catalog-source-namespace'] || flags.chenamespace
-              subscription = this.constructSubscription(SUBSCRIPTION_NAME, flags['package-manifest-name'], flags.chenamespace, catalogSourceNamespace, flags['olm-channel'], ctx.sourceName, ctx.approvalStarategy, ctx.startingCSV)
+              const catalogSourceNamespace = flags['catalog-source-namespace'] || ctx.operatorNamespace
+              subscription = this.constructSubscription(SUBSCRIPTION_NAME, flags['package-manifest-name'], ctx.operatorNamespace, catalogSourceNamespace, flags['olm-channel'], ctx.sourceName, ctx.approvalStarategy, ctx.startingCSV)
             } else if (VersionHelper.isDeployingStableVersion(flags) || flags['olm-channel'] === OLM_STABLE_CHANNEL_NAME) {
               // stable Che CatalogSource
-              subscription = this.constructSubscription(SUBSCRIPTION_NAME, DEFAULT_CHE_OLM_PACKAGE_NAME, flags.chenamespace, ctx.defaultCatalogSourceNamespace, OLM_STABLE_CHANNEL_NAME, ctx.catalogSourceNameStable, ctx.approvalStarategy, ctx.startingCSV)
+              subscription = this.constructSubscription(SUBSCRIPTION_NAME, DEFAULT_CHE_OLM_PACKAGE_NAME, ctx.operatorNamespace, ctx.defaultCatalogSourceNamespace, OLM_STABLE_CHANNEL_NAME, ctx.catalogSourceNameStable, ctx.approvalStarategy, ctx.startingCSV)
+            } else if (flags['olm-channel'] === STABLE_ALL_NAMESPACES_CHANNEL_NAME) {
+              // stable Che CatalogSource
+              subscription = this.constructSubscription(SUBSCRIPTION_NAME, DEFAULT_CHE_OLM_PACKAGE_NAME, ctx.operatorNamespace, ctx.defaultCatalogSourceNamespace, STABLE_ALL_NAMESPACES_CHANNEL_NAME, ctx.catalogSourceNameStable, ctx.approvalStarategy, ctx.startingCSV)
             } else {
-              // nightly Che CatalogSource
-              subscription = this.constructSubscription(SUBSCRIPTION_NAME, `eclipse-che-preview-${ctx.generalPlatformName}`, flags.chenamespace, flags.chenamespace, OLM_NIGHTLY_CHANNEL_NAME, NIGHTLY_CATALOG_SOURCE_NAME, ctx.approvalStarategy, ctx.startingCSV)
+              // next Che CatalogSource
+              subscription = this.constructSubscription(SUBSCRIPTION_NAME, `eclipse-che-preview-${ctx.generalPlatformName}`, ctx.operatorNamespace, ctx.operatorNamespace, OLM_NEXT_CHANNEL_NAME, NEXT_CATALOG_SOURCE_NAME, ctx.approvalStarategy, ctx.startingCSV)
             }
             await kube.createOperatorSubscription(subscription)
             task.title = `${task.title}...created new one.`
           }
-        }
+        },
       },
       {
         title: 'Wait while subscription is ready',
         task: async (ctx: any, task: any) => {
-          const installPlan = await kube.waitOperatorSubscriptionReadyForApproval(flags.chenamespace, SUBSCRIPTION_NAME, 600)
+          const installPlan = await kube.waitOperatorSubscriptionReadyForApproval(ctx.operatorNamespace, SUBSCRIPTION_NAME, 600)
           ctx.installPlanName = installPlan.name
           task.title = `${task.title}...done.`
-        }
+        },
       },
       {
         title: 'Approve installation',
         enabled: ctx => ctx.approvalStarategy === 'Manual',
         task: async (ctx: any, task: any) => {
-          await kube.approveOperatorInstallationPlan(ctx.installPlanName, flags.chenamespace)
+          await kube.approveOperatorInstallationPlan(ctx.installPlanName, ctx.operatorNamespace)
           task.title = `${task.title}...done.`
-        }
+        },
       },
       {
         title: 'Wait while operator installed',
         task: async (ctx: any, task: any) => {
-          await kube.waitUntilOperatorIsInstalled(ctx.installPlanName, flags.chenamespace)
+          await kube.waitUntilOperatorIsInstalled(ctx.installPlanName, ctx.operatorNamespace)
           task.title = `${task.title}...done.`
-        }
+        },
       },
       {
         title: 'Set custom operator image',
@@ -193,7 +202,7 @@ export class OLMTasks {
           const jsonPatch = [{ op: 'replace', path: '/spec/install/spec/deployments/0/spec/template/spec/containers/0/image', value: flags['che-operator-image'] }]
           await kube.patchClusterServiceVersion(csv.metadata.namespace!, csv.metadata.name!, jsonPatch)
           task.title = `${task.title}... changed to ${flags['che-operator-image']}.`
-        }
+        },
       },
       {
         title: 'Prepare CodeReady Workspaces cluster CR',
@@ -205,13 +214,13 @@ export class OLMTasks {
           }
 
           if (!ctx.customCR) {
-            ctx.defaultCR = await this.getCRFromCSV(kube, flags.chenamespace)
+            ctx.defaultCR = await this.getCRFromCSV(kube, ctx.operatorNamespace)
           }
 
           task.title = `${task.title}...Done.`
-        }
+        },
       },
-      createEclipseCheCluster(flags, kube)
+      createEclipseCheCluster(flags, kube),
     ], { renderer: flags['listr-renderer'] as any })
   }
 
@@ -221,21 +230,21 @@ export class OLMTasks {
       this.isOlmPreInstalledTask(command, kube),
       {
         title: 'Check if operator group exists',
-        task: async (_ctx: any, task: any) => {
-          if (!await kube.operatorGroupExists(OPERATOR_GROUP_NAME, flags.chenamespace)) {
+        task: async (ctx: any, task: any) => {
+          if (!await kube.operatorGroupExists(OPERATOR_GROUP_NAME, ctx.operatorNamespace)) {
             command.error(`Unable to find operator group ${OPERATOR_GROUP_NAME}`)
           }
           task.title = `${task.title}...done.`
-        }
+        },
       },
       {
         title: 'Check if operator subscription exists',
-        task: async (_ctx: any, task: any) => {
-          if (!await kube.operatorSubscriptionExists(SUBSCRIPTION_NAME, flags.chenamespace)) {
+        task: async (ctx: any, task: any) => {
+          if (!await kube.operatorSubscriptionExists(SUBSCRIPTION_NAME, ctx.operatorNamespace)) {
             command.error(`Unable to find operator subscription ${SUBSCRIPTION_NAME}`)
           }
           task.title = `${task.title}...done.`
-        }
+        },
       },
     ], { renderer: flags['listr-renderer'] as any })
   }
@@ -246,7 +255,10 @@ export class OLMTasks {
       {
         title: 'Get operator installation plan',
         task: async (ctx: any, task: any) => {
-          const subscription: Subscription = await kube.getOperatorSubscription(SUBSCRIPTION_NAME, flags.chenamespace)
+          const subscription = await kube.getOperatorSubscription(SUBSCRIPTION_NAME, ctx.operatorNamespace)
+          if (!subscription) {
+            throw new Error(`Subscription '${SUBSCRIPTION_NAME}' not found in namespace '${ctx.operatorNamespace}'.`)
+          }
 
           if (subscription.status) {
             if (subscription.status.state === 'AtLatestKnown') {
@@ -276,26 +288,26 @@ export class OLMTasks {
             }
           }
           command.error('Unable to find installation plan to update.')
-        }
+        },
       },
       {
         title: 'Approve installation',
         enabled: (ctx: any) => ctx.installPlanName,
         task: async (ctx: any, task: any) => {
-          await kube.approveOperatorInstallationPlan(ctx.installPlanName, flags.chenamespace)
+          await kube.approveOperatorInstallationPlan(ctx.installPlanName, ctx.operatorNamespace)
           task.title = `${task.title}...done.`
-        }
+        },
       },
       {
         title: 'Wait while newer operator installed',
         enabled: (ctx: any) => ctx.installPlanName,
         task: async (ctx: any, task: any) => {
-          await kube.waitUntilOperatorIsInstalled(ctx.installPlanName, flags.chenamespace, 60)
+          await kube.waitUntilOperatorIsInstalled(ctx.installPlanName, ctx.operatorNamespace, 60)
           ctx.highlightedMessages.push(`Operator is updated from ${ctx.currentVersion} to ${ctx.nextVersion} version`)
           task.title = `${task.title}...done.`
-        }
+        },
       },
-      patchingEclipseCheCluster(flags, kube, command)
+      patchingEclipseCheCluster(flags, kube, command),
     ], { renderer: flags['listr-renderer'] as any })
   }
 
@@ -305,17 +317,29 @@ export class OLMTasks {
       {
         title: 'Check if OLM is pre-installed on the platform',
         task: async (ctx: any, task: any) => {
-          ctx.isPreInstalledOLM = await kube.isPreInstalledOLM() ? true : false
+          ctx.isPreInstalledOLM = Boolean(await kube.isPreInstalledOLM())
           task.title = `${task.title}: ${ctx.isPreInstalledOLM}...OK`
-        }
+        },
+      },
+      {
+        title: `Check if operator is installed in ${DEFAULT_OPENSHIFT_OPERATORS_NS_NAME} namespace`,
+        task: async (ctx: any, task: any) => {
+          if (await kube.operatorSubscriptionExists(SUBSCRIPTION_NAME, DEFAULT_OPENSHIFT_OPERATORS_NS_NAME)) {
+            ctx.operatorNamespace = DEFAULT_OPENSHIFT_OPERATORS_NS_NAME
+            task.title = `${task.title}...Found`
+          } else {
+            ctx.operatorNamespace = flags.chenamespace || DEFAULT_CHE_NAMESPACE
+            task.title = `${task.title}...Not Found`
+          }
+        },
       },
       {
         title: `Delete(OLM) operator subscription ${SUBSCRIPTION_NAME}`,
         enabled: ctx => ctx.isPreInstalledOLM,
-        task: async (_ctx: any, task: any) => {
-          await kube.deleteOperatorSubscription(SUBSCRIPTION_NAME, flags.chenamespace)
+        task: async (ctx: any, task: any) => {
+          await kube.deleteOperatorSubscription(SUBSCRIPTION_NAME, ctx.operatorNamespace)
           task.title = `${task.title}...OK`
-        }
+        },
       },
       {
         title: 'Delete(OLM) CodeReady Workspaces cluster service versions',
@@ -325,43 +349,43 @@ export class OLMTasks {
           const csvsToDelete = csvs.items.filter(csv => csv.metadata.name!.startsWith(CVS_PREFIX))
           csvsToDelete.forEach(csv => kube.deleteClusterServiceVersion(flags.chenamespace, csv.metadata.name!))
           task.title = `${task.title}...OK`
-        }
+        },
       },
       {
         title: `Delete(OLM) operator group ${OPERATOR_GROUP_NAME}`,
         enabled: ctx => ctx.isPreInstalledOLM,
-        task: async (_ctx: any, task: any) => {
-          await kube.deleteOperatorGroup(OPERATOR_GROUP_NAME, flags.chenamespace)
+        task: async (ctx: any, task: any) => {
+          await kube.deleteOperatorGroup(OPERATOR_GROUP_NAME, ctx.operatorNamespace)
           task.title = `${task.title}...OK`
-        }
+        },
       },
       {
         title: `Delete(OLM) custom catalog source ${CUSTOM_CATALOG_SOURCE_NAME}`,
-        task: async (_ctx: any, task: any) => {
-          await kube.deleteCatalogSource(flags.chenamespace, CUSTOM_CATALOG_SOURCE_NAME)
+        task: async (ctx: any, task: any) => {
+          await kube.deleteCatalogSource(ctx.operatorNamespace, CUSTOM_CATALOG_SOURCE_NAME)
           task.title = `${task.title}...OK`
-        }
+        },
       },
       {
-        title: `Delete(OLM) nigthly catalog source ${NIGHTLY_CATALOG_SOURCE_NAME}`,
-        task: async (_ctx: any, task: any) => {
-          await kube.deleteCatalogSource(flags.chenamespace, NIGHTLY_CATALOG_SOURCE_NAME)
+        title: `Delete(OLM) nigthly catalog source ${NEXT_CATALOG_SOURCE_NAME}`,
+        task: async (ctx: any, task: any) => {
+          await kube.deleteCatalogSource(ctx.operatorNamespace, NEXT_CATALOG_SOURCE_NAME)
           task.title = `${task.title}...OK`
-        }
+        },
       },
       {
         title: `Delete role ${this.prometheusRoleName}`,
         task: async (_ctx: any, task: any) => {
           await kube.deleteRole(this.prometheusRoleName, flags.chenamespace)
           task.title = await `${task.title}...OK`
-        }
+        },
       },
       {
         title: `Delete role binding ${this.prometheusRoleName}`,
         task: async (_ctx: any, task: any) => {
           await kube.deleteRoleBinding(this.prometheusRoleName, flags.chenamespace)
           task.title = await `${task.title}...OK`
-        }
+        },
       },
     ]
   }
@@ -376,7 +400,7 @@ export class OLMTasks {
           command.error('OLM is required for installation CodeReady Workspaces with installer flag \'olm\'')
         }
         task.title = `${task.title}...done.`
-      }
+      },
     }
   }
 
@@ -386,7 +410,7 @@ export class OLMTasks {
       kind: 'Subscription',
       metadata: {
         name,
-        namespace
+        namespace,
       },
       spec: {
         channel,
@@ -395,7 +419,7 @@ export class OLMTasks {
         source: sourceName,
         sourceNamespace,
         startingCSV,
-      }
+      },
     }
   }
 
@@ -404,7 +428,7 @@ export class OLMTasks {
       apiVersion: 'operators.coreos.com/v1alpha1',
       kind: 'CatalogSource',
       metadata: {
-        name: NIGHTLY_CATALOG_SOURCE_NAME,
+        name: NEXT_CATALOG_SOURCE_NAME,
         namespace,
       },
       spec: {
@@ -412,27 +436,31 @@ export class OLMTasks {
         sourceType: 'grpc',
         updateStrategy: {
           registryPoll: {
-            interval: '15m'
-          }
-        }
-      }
+            interval: '15m',
+          },
+        },
+      },
     }
   }
 
-  private async getCRFromCSV(kube: KubeHelper, cheNamespace: string): Promise<any> {
-    const subscription: Subscription = await kube.getOperatorSubscription(SUBSCRIPTION_NAME, cheNamespace)
+  private async getCRFromCSV(kube: KubeHelper, namespace: string): Promise<any> {
+    const subscription = await kube.getOperatorSubscription(SUBSCRIPTION_NAME, namespace)
+    if (!subscription) {
+      throw new Error(`Subscription '${SUBSCRIPTION_NAME}' not found in namespace '${namespace}'.`)
+    }
+
     const currentCSV = subscription.status!.currentCSV
-    const csv = await kube.getCSV(currentCSV, cheNamespace)
+    const csv = await kube.getCSV(currentCSV, namespace)
     if (csv && csv.metadata.annotations) {
       const CRRaw = csv.metadata.annotations!['alm-examples']
-      return (yaml.safeLoad(CRRaw) as Array<any>)[0]
+      return (yaml.load(CRRaw) as Array<any>).find(cr => cr.kind === 'CheCluster')
     } else {
       throw new Error(`Unable to retrieve Che cluster CR definition from CSV: ${currentCSV}`)
     }
   }
 
   private getOlmNamespaceLabels(flags: any): any {
-    //The label values must be strings
+    // The label values must be strings
     if (flags['cluster-monitoring'] && flags.platform === 'openshift') {
       return { 'openshift.io/cluster-monitoring': 'true' }
     }
